package    # hide from pause
    SBOM::CycloneDX::Vulnerability::Source;

use Carp;
use Moo;
extends 'SBOM::CycloneDX::Source';

sub BUILD {
    Carp::carp 'DEPRECATED: SBOM::CycloneDX::Vulnerability::Source, use SBOM::CycloneDX::Source instead';
}

1;

